@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::MandatoryOnTransition;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 =head1 NAME
 
@@ -840,7 +840,7 @@ sub CheckMandatoryFields {
             $submitted = $submitted ? $submitted->{(sort keys %$submitted)[0]} : {};
 
             my @values;
-            for my $argtype (qw/Values Value/) {
+            for my $argtype (qw/Values Value Upload/) {
                 next if @values;
                 @values = HTML::Mason::Commands::_NormalizeObjectCustomFieldValue(
                     CustomField => $cf,
@@ -852,7 +852,12 @@ sub CheckMandatoryFields {
             ($value) = @values;
         }
         else {
-            my $arg   = "Object-RT::Ticket-".$TicketId."-CustomField-".$cf->Id."-Value";
+            my $arg;
+            if ( $cf->Type =~ m/^(Binary|Image)$/ ) {
+                $arg   = "Object-RT::Ticket-".$TicketId."-CustomField-".$cf->Id."-Upload";
+            } else {
+                $arg   = "Object-RT::Ticket-".$TicketId."-CustomField-".$cf->Id."-Value";
+            }
             $value = ($ARGSRef->{"${arg}s-Magic"} and exists $ARGSRef->{"${arg}s"}) ? $ARGSRef->{$arg . "s"} : $ARGSRef->{$arg};
             ($value) = grep length, map {
                 s/\r+\n/\n/g;
@@ -991,7 +996,7 @@ or via the web at
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2012-2022 by Best Pracical Solutions, LLC.
+This software is Copyright (c) 2012-2023 by Best Pracical Solutions, LLC.
 
 This is free software, licensed under:
 
